XtsCtsProcessor

Struct XtsCtsProcessor 

pub struct XtsCtsProcessor<'a, 'b> { /* private fields */ }
Handles ciphertext stealing in order to allow non-BlockSize lengths to be used as long as they are >= BlockSize. To be used with encrypt|decrypt_with_backend. Conforms to IEEE 1619-2007.

Implementations

Source

impl<'a, 'b> XtsCtsProcessor<'a, 'b>

pub fn new( tweak: Tweak, src: PtrByteSlice<'a>, dst: MutPtrByteSlice<'b>, ) -> Self

tweak should be encrypted. src and dst must have the same length and be 16 byte aligned.

pub fn new_in_place( tweak: Tweak, buf: MutPtrByteSlice<'a>, ) -> XtsCtsProcessor<'a, 'a>

Creates an XtsCtsProcessor for in-place operation on a single buffer.